@@ -1,14 +1,14 @@
 package Org::To::VCF;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use vars qw($VERSION);
 
-use File::Slurp::Tiny qw(read_file write_file);
+use File::Slurper qw(read_text write_text);
 use Org::Document;
 use Org::Dump qw();
 use Scalar::Util qw(blessed);
@@ -109,8 +109,7 @@ sub org_to_vcf {
 
     my $doc;
     if ($args{source_file}) {
-        $doc = Org::Document->new(from_string =>
-                                      scalar read_file($args{source_file}));
+        $doc = Org::Document->new(from_string => read_text($args{source_file}));
     } elsif (defined($args{source_str})) {
         $doc = Org::Document->new(from_string => $args{source_str});
     } else {
@@ -130,7 +129,7 @@ sub org_to_vcf {
     $obj->export($doc);
     #$log->tracef("vcf = %s", $vcf);
     if ($args{target_file}) {
-        write_file($args{target_file}, $vcf->export);
+        write_text($args{target_file}, $vcf->export);
         return [200, "OK"];
     } else {
         return [200, "OK", $vcf->export];
@@ -177,8 +176,8 @@ sub _format_phone {
 sub _parse_field {
     my ($self, $fields, $key, $textval, $vals) = @_;
     $vals = [$vals] unless ref($vals) eq 'ARRAY';
-    if ($log->is_trace) {
-        $log->tracef("parsing field: key=%s, textval=%s, vals=%s",
+    if (log_is_trace) {
+        log_trace("parsing field: key=%s, textval=%s, vals=%s",
                      $key, $textval,
                      [map {blessed($_) && $_->isa('Org::Element') ?
                                Org::Dump::dump_element($_) : $_} @$vals]);
@@ -188,7 +187,7 @@ sub _parse_field {
     if ($key =~ /^((?:full\s?)?name |
                      nama(?:\slengkap)?)$/ix) {
         $fields->{FN} = $textval;
-        $log->tracef("found FN field: %s", $textval);
+        log_trace("found FN field: %s", $textval);
     } elsif ($key =~ /^(birthday |
                           ultah|ulang\stahun|(?:tanggal\s|tgg?l\s)?lahir)$/ix) {
         # find the first timestamp field
@@ -201,13 +200,13 @@ sub _parse_field {
         }
         if (@ts) {
             $fields->{BDAY} = $ts[0]->datetime->ymd;
-            $log->tracef("found BDAY field: %s", $fields->{BDAY});
+            log_trace("found BDAY field: %s", $fields->{BDAY});
             $fields->{_has_contact} = 1;
         } else {
             # or from a regex match
             if ($textval =~ /(\d{4}-\d{2}-\d{2})/) {
                 $fields->{BDAY} = $1;
-                $log->tracef("found BDAY field: %s", $fields->{BDAY});
+                log_trace("found BDAY field: %s", $fields->{BDAY});
                 $fields->{_has_contact} = 1;
             }
         }
@@ -236,12 +235,12 @@ sub _parse_field {
             $type = "mobile";
         }
         $fields->{TEL}{$type} = $self->_format_phone($textval);
-        $log->tracef("found TEL ($type) field: %s", $fields->{TEL}{$type});
+        log_trace("found TEL ($type) field: %s", $fields->{TEL}{$type});
         $fields->{_has_contact} = 1;
     } elsif ($key =~ /^((?:e[-]?mail|mail) |
                           (?:i[ -]?mel|surel))$/ix) {
         $fields->{EMAIL} = $textval;
-        $log->tracef("found EMAIL field: %s", $fields->{EMAIL});
+        log_trace("found EMAIL field: %s", $fields->{EMAIL});
         $fields->{_has_contact} = 1;
     } else {
         # note is from note fields or everything that does not have field names
@@ -250,7 +249,7 @@ sub _parse_field {
         if ($self->export_notes && $fields->{_num_notes}++ < 3) {
             $fields->{NOTE} .= ( $fields->{NOTE} ? "\n" : "" ) .
                 ($key ? "$key: " : "") . $textval;
-            $log->tracef("%s NOTE field: %s",
+            log_trace("%s NOTE field: %s",
                          $fields->{_num_notes} == 1 ? "found" : "add",
                          $fields->{NOTE});
         }
@@ -298,9 +297,9 @@ sub _add_vcard {
 sub export_headline {
     my ($self, $elem) = @_;
 
-    if ($log->is_trace) {
+    if (log_is_trace) {
         require String::Escape;
-        $log->tracef("exporting headline %s (%s) ...", ref($elem),
+        log_trace("exporting headline %s (%s) ...", ref($elem),
                      String::Escape::elide(
                          String::Escape::printable($elem->as_string), 30));
     }
@@ -343,7 +342,7 @@ sub export_headline {
         }
     }
 
-    $log->tracef("fields: %s", $fields);
+    log_trace("fields: %s", $fields);
     $self->_add_vcard($fields) if $fields->{_has_contact};
 
     $self->export_headline($_) for @subhl;
@@ -381,7 +380,7 @@ Org::To::VCF - Export contacts in Org document to VCF (vCard addressbook)
 
 =head1 VERSION
 
-This document describes version 0.08 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2015-09-03.
+This document describes version 0.09 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -435,10 +434,16 @@ drawer:
 =head1 FUNCTIONS
 
 
-=head2 org_to_vcf(%args) -> [status, msg, result, meta]
+=head2 org_to_vcf
+
+Usage:
+
+ org_to_vcf(%args) -> [status, msg, result, meta]
 
 Export contacts in Org document to VCF (vCard addressbook).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -506,16 +511,6 @@ Return value:  (any)
 
 =for Pod::Coverage ^(default_country|export|export_.+)$
 
-=head1 SEE ALSO
-
-For more information about Org document format, visit http://orgmode.org/
-
-L<Org::Parser>
-
-L<Text::vCard>
-
-Org-contacts: http://julien.danjou.info/projects/emacs-packages#org-contacts
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Org-To-VCF>.
@@ -532,13 +527,23 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+For more information about Org document format, visit http://orgmode.org/
+
+L<Org::Parser>
+
+L<Text::vCard>
+
+Org-contacts: http://julien.danjou.info/projects/emacs-packages#org-contacts
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
